@@ -25,13 +25,13 @@ function(author, datetimestamp, description, heading, id, language, origin, ...,
     if (!is.null(meta$origin))
        meta$origin <- as.character(meta$origin)
 
-    structure(meta, class = "TextDocumentMeta")
+    class(meta) <- "TextDocumentMeta"
+    meta
 }
 
 print.TextDocumentMeta <-
 function(x, ...)
 {
-    writeLines("Metadata:")
     cat(sprintf("  %s: %s",
                 format(names(x), justify = "left"),
                 sapply(x, as.character)),
@@ -47,7 +47,27 @@ function(..., meta = NULL)
 
     stopifnot(is.list(meta))
 
-    structure(meta, class = "CorpusMeta")
+    class(meta) <- "CorpusMeta"
+    meta
+}
+
+meta.SimpleCorpus <-
+function(x, tag = NULL, type = c("indexed", "corpus"), ...)
+{
+    if (identical(tag, "id")) {
+        n <- names(content(x))
+        return(if (is.null(n)) as.character(seq_along(x)) else n)
+    }
+
+    if (!is.null(tag) && missing(type))
+        type <- if (tag %in% names(x$meta)) "corpus" else "indexed"
+    type <- match.arg(type)
+    if (identical(type, "indexed"))
+        if (is.null(tag)) x$dmeta else x$dmeta[tag]
+    else if (identical(type, "corpus"))
+        if (is.null(tag)) x$meta else x$meta[[tag]]
+    else
+        stop("invalid type")
 }
 
 meta.VCorpus <- meta.PCorpus <-
@@ -68,9 +88,19 @@ function(x, tag = NULL, type = c("indexed", "corpus", "local"), ...)
     else
         stop("invalid type")
 }
-meta.TextDocument <-
-function(x, tag = NULL, ...)
-    if (is.null(tag)) x$meta else x$meta[[tag]]
+
+`meta<-.SimpleCorpus` <-
+function(x, tag, type = c("indexed", "corpus"), ..., value)
+{
+    type <- match.arg(type)
+    if (identical(type, "indexed"))
+        x$dmeta[, tag] <- value
+    else if (type == "corpus")
+        x$meta[[tag]] <- value
+    else
+        stop("invalid type")
+    x
+}
 
 `meta<-.VCorpus` <- `meta<-.PCorpus` <-
 function(x, tag, type = c("indexed", "corpus", "local"), ..., value)
@@ -87,12 +117,6 @@ function(x, tag, type = c("indexed", "corpus", "local"), ..., value)
         stop("invalid type")
     x
 }
-`meta<-.TextDocument` <-
-function(x, tag, ..., value)
-{
-    x$meta[[tag]] <- value
-    x
-}
 
 # Simple Dublin Core to tm metadata mapping
 # http://en.wikipedia.org/wiki/Dublin_core#Simple_Dublin_Core
@@ -120,10 +144,12 @@ function(x, tag = NULL)
     tmm <- unlist(Dublin_Core_tm_map, use.names = FALSE)
     dcm <- names(Dublin_Core_tm_map)
 
-    if (is.null(tag))
-        structure(lapply(tmm, function(t) meta(x, t)), names = dcm,
-                  class = "TextDocumentMeta")
-    else
+    if (is.null(tag)) {
+        m <- lapply(tmm, function(t) meta(x, t))
+        names(m) <- dcm
+        class(m) <- "TextDocumentMeta"
+        m
+    } else
         meta(x, tmm[charmatch(tolower(tag), dcm)])
 }
 
